pub struct TradeStream;Expand description
Typed wrapper for public trade stream data.
Bybit sends an array of trades in each message.
Implementations
Sourceimpl TradeStream
impl TradeStream
Sourcepub fn parse(data: &Value) -> Result<Vec<PublicTrade>>
pub fn parse(data: &Value) -> Result<Vec<PublicTrade>>
Parse raw WS data into a vector of trades.
Sourcepub fn matches_topic(topic: &str) -> bool
pub fn matches_topic(topic: &str) -> bool
Check if the given topic matches a public trade channel.